==> jc-1.4.0.tar.gz: java/io/PipedOutputStream.h <==
// public class java.io.PipedOutputStream

// class file dependencies
// @dep_class 4026d3144d6654d8 java_io_OutputStream
// @dep_class 18bbf9ed8a0af8fd java_io_PipedOutputStream
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_io_OutputStream

#include "java/io/OutputStream.h"

#ifndef _JC_java_io_PipedOutputStream_H_
#define _JC_java_io_PipedOutputStream_H_

// Forward structure declarations
struct _jc_java_io_PipedInputStream$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_io_PipedOutputStream$sub_refs	_jc_java_io_PipedOutputStream$sub_refs;
typedef struct _jc_java_io_PipedOutputStream$sub_nonrefs	_jc_java_io_PipedOutputStream$sub_nonrefs;
typedef struct _jc_java_io_PipedOutputStream$refs	_jc_java_io_PipedOutputStream$refs;
typedef struct _jc_java_io_PipedOutputStream$nonrefs	_jc_java_io_PipedOutputStream$nonrefs;
typedef struct _jc_java_io_PipedOutputStream$object	_jc_java_io_PipedOutputStream$object;

typedef const struct _jc_java_io_PipedOutputStream$vmethods	_jc_java_io_PipedOutputStream$vmethods;
typedef const struct _jc_java_io_PipedOutputStream$vtable	_jc_java_io_PipedOutputStream$vtable;
typedef const struct _jc_java_io_PipedOutputStream$vtype	_jc_java_io_PipedOutputStream$vtype;

// Constructors
extern void _jc_java_io_PipedOutputStream$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_io_PipedOutputStream$object *);
extern void _jc_java_io_PipedOutputStream$method$_init$d80b18db739abf08(_jc_env *, struct _jc_java_io_PipedOutputStream$object *, struct _jc_java_io_PipedInputStream$object *);

// Virtual methods
extern void _jc_java_io_PipedOutputStream$method$close$6aba8b329fddcd79(_jc_env *, struct _jc_java_io_PipedOutputStream$object *);
extern void _jc_java_io_PipedOutputStream$method$connect$018aab6a473390b6(_jc_env *, struct _jc_java_io_PipedOutputStream$object *, struct _jc_java_io_PipedInputStream$object *);
extern void _jc_java_io_PipedOutputStream$method$flush$9dedb7d85e88cf56(_jc_env *, struct _jc_java_io_PipedOutputStream$object *);
extern void _jc_java_io_PipedOutputStream$method$write$6377ac6964854eb2(_jc_env *, struct _jc_java_io_PipedOutputStream$object *, jint);
extern void _jc_java_io_PipedOutputStream$method$write$306a698343ec27e8(_jc_env *, struct _jc_java_io_PipedOutputStream$object *, struct _jc_byte_array *, jint, jint);

// Virtual method descriptors
extern _jc_method _jc_java_io_PipedOutputStream$method_info$close$6aba8b329fddcd79;
extern _jc_method _jc_java_io_PipedOutputStream$method_info$connect$018aab6a473390b6;
extern _jc_method _jc_java_io_PipedOutputStream$method_info$flush$9dedb7d85e88cf56;
extern _jc_method _jc_java_io_PipedOutputStream$method_info$write$6377ac6964854eb2;
extern _jc_method _jc_java_io_PipedOutputStream$method_info$write$306a698343ec27e8;

// Virtual methods structure
struct _jc_java_io_PipedOutputStream$vmethods {
	void	(*close$6aba8b329fddcd79)(_jc_env *, struct _jc_java_io_PipedOutputStream$object *);
	void	(*connect$018aab6a473390b6)(_jc_env *, struct _jc_java_io_PipedOutputStream$object *, struct _jc_java_io_PipedInputStream$object *);
	void	(*flush$9dedb7d85e88cf56)(_jc_env *, struct _jc_java_io_PipedOutputStream$object *);
	void	(*write$6377ac6964854eb2)(_jc_env *, struct _jc_java_io_PipedOutputStream$object *, jint);
	void	(*write$306a698343ec27e8)(_jc_env *, struct _jc_java_io_PipedOutputStream$object *, struct _jc_byte_array *, jint, jint);
};

// Vtable
struct _jc_java_io_PipedOutputStream$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_io_OutputStream$vmethods	java_io_OutputStream;
	_jc_java_io_PipedOutputStream$vmethods	java_io_PipedOutputStream;
};

// Vtype
struct _jc_java_io_PipedOutputStream$vtype {
	_jc_type			type;
	_jc_java_io_PipedOutputStream$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_io_PipedOutputStream$sub_refs {
	struct _jc_java_io_PipedInputStream$object	*sink;
};

// Reference instance fields (object)
struct _jc_java_io_PipedOutputStream$refs {
    _jc_java_io_PipedOutputStream$sub_refs	java_io_PipedOutputStream;
    _jc_java_io_OutputStream$sub_refs	java_io_OutputStream;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_io_PipedOutputStream$sub_nonrefs {
	jboolean	closed;
};

// Non-reference instance fields (object)
struct _jc_java_io_PipedOutputStream$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_io_OutputStream$sub_nonrefs	java_io_OutputStream;
    _jc_java_io_PipedOutputStream$sub_nonrefs	java_io_PipedOutputStream;
};

// Object instance structure
struct _jc_java_io_PipedOutputStream$object {
	_jc_java_io_PipedOutputStream$refs	refs[0];
	_jc_word		lockword;
	_jc_java_io_PipedOutputStream$vtype	*vtype;
	_jc_java_io_PipedOutputStream$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_io_PipedOutputStream$vtype _jc_java_io_PipedOutputStream$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_io_PipedOutputStream, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_io_PipedOutputStream$class_object;

#endif	/* _JC_java_io_PipedOutputStream_H_ */

==> jc-1.4.6.tar.gz: java/io/PipedOutputStream.h <==
// public class java.io.PipedOutputStream

// class file dependencies
// @dep_class 4026d3144d6654d8 java_io_OutputStream
// @dep_class 18bbf9ed8a0af8fd java_io_PipedOutputStream
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_io_OutputStream

#include "java/io/OutputStream.h"

#ifndef _JC_java_io_PipedOutputStream_H_
#define _JC_java_io_PipedOutputStream_H_

// Forward structure declarations
struct _jc_java_io_PipedInputStream$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_io_PipedOutputStream$sub_refs	_jc_java_io_PipedOutputStream$sub_refs;
typedef struct _jc_java_io_PipedOutputStream$sub_nonrefs	_jc_java_io_PipedOutputStream$sub_nonrefs;
typedef struct _jc_java_io_PipedOutputStream$refs	_jc_java_io_PipedOutputStream$refs;
typedef struct _jc_java_io_PipedOutputStream$nonrefs	_jc_java_io_PipedOutputStream$nonrefs;
typedef struct _jc_java_io_PipedOutputStream$object	_jc_java_io_PipedOutputStream$object;

typedef const struct _jc_java_io_PipedOutputStream$vmethods	_jc_java_io_PipedOutputStream$vmethods;
typedef const struct _jc_java_io_PipedOutputStream$vtable	_jc_java_io_PipedOutputStream$vtable;
typedef const struct _jc_java_io_PipedOutputStream$vtype	_jc_java_io_PipedOutputStream$vtype;

// Constructors
extern void _jc_java_io_PipedOutputStream$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_io_PipedOutputStream$object *) _JC_JCNI_ATTR;
extern void _jc_java_io_PipedOutputStream$method$_init$d80b18db739abf08(_jc_env *, struct _jc_java_io_PipedOutputStream$object *, struct _jc_java_io_PipedInputStream$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_java_io_PipedOutputStream$method$close$6aba8b329fddcd79(_jc_env *, struct _jc_java_io_PipedOutputStream$object *) _JC_JCNI_ATTR;
extern void _jc_java_io_PipedOutputStream$method$connect$018aab6a473390b6(_jc_env *, struct _jc_java_io_PipedOutputStream$object *, struct _jc_java_io_PipedInputStream$object *) _JC_JCNI_ATTR;
extern void _jc_java_io_PipedOutputStream$method$flush$9dedb7d85e88cf56(_jc_env *, struct _jc_java_io_PipedOutputStream$object *) _JC_JCNI_ATTR;
extern void _jc_java_io_PipedOutputStream$method$write$6377ac6964854eb2(_jc_env *, struct _jc_java_io_PipedOutputStream$object *, jint) _JC_JCNI_ATTR;
extern void _jc_java_io_PipedOutputStream$method$write$306a698343ec27e8(_jc_env *, struct _jc_java_io_PipedOutputStream$object *, struct _jc_byte_array *, jint, jint) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_io_PipedOutputStream$method_info$close$6aba8b329fddcd79;
extern _jc_method _jc_java_io_PipedOutputStream$method_info$connect$018aab6a473390b6;
extern _jc_method _jc_java_io_PipedOutputStream$method_info$flush$9dedb7d85e88cf56;
extern _jc_method _jc_java_io_PipedOutputStream$method_info$write$6377ac6964854eb2;
extern _jc_method _jc_java_io_PipedOutputStream$method_info$write$306a698343ec27e8;

// Virtual methods structure
struct _jc_java_io_PipedOutputStream$vmethods {
	void	(*close$6aba8b329fddcd79)(_jc_env *, struct _jc_java_io_PipedOutputStream$object *) _JC_JCNI_ATTR;
	void	(*connect$018aab6a473390b6)(_jc_env *, struct _jc_java_io_PipedOutputStream$object *, struct _jc_java_io_PipedInputStream$object *) _JC_JCNI_ATTR;
	void	(*flush$9dedb7d85e88cf56)(_jc_env *, struct _jc_java_io_PipedOutputStream$object *) _JC_JCNI_ATTR;
	void	(*write$6377ac6964854eb2)(_jc_env *, struct _jc_java_io_PipedOutputStream$object *, jint) _JC_JCNI_ATTR;
	void	(*write$306a698343ec27e8)(_jc_env *, struct _jc_java_io_PipedOutputStream$object *, struct _jc_byte_array *, jint, jint) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_io_PipedOutputStream$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_io_OutputStream$vmethods	java_io_OutputStream;
	_jc_java_io_PipedOutputStream$vmethods	java_io_PipedOutputStream;
};

// Vtype
struct _jc_java_io_PipedOutputStream$vtype {
	_jc_type			type;
	_jc_java_io_PipedOutputStream$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_io_PipedOutputStream$sub_refs {
	struct _jc_java_io_PipedInputStream$object	*sink;
};

// Reference instance fields (object)
struct _jc_java_io_PipedOutputStream$refs {
    _jc_java_io_PipedOutputStream$sub_refs	java_io_PipedOutputStream;
    _jc_java_io_OutputStream$sub_refs	java_io_OutputStream;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_io_PipedOutputStream$sub_nonrefs {
	jboolean	closed;
};

// Non-reference instance fields (object)
struct _jc_java_io_PipedOutputStream$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_io_OutputStream$sub_nonrefs	java_io_OutputStream;
    _jc_java_io_PipedOutputStream$sub_nonrefs	java_io_PipedOutputStream;
};

// Object instance structure
struct _jc_java_io_PipedOutputStream$object {
	_jc_java_io_PipedOutputStream$refs	refs[0];
	_jc_word		lockword;
	_jc_java_io_PipedOutputStream$vtype	*vtype;
	_jc_java_io_PipedOutputStream$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_io_PipedOutputStream$vtype _jc_java_io_PipedOutputStream$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_io_PipedOutputStream, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_io_PipedOutputStream$class_object;

#endif	/* _JC_java_io_PipedOutputStream_H_ */
